#ifndef APP_H
#define APP_H

#include <delays.h>

typedef unsigned char		BYTE;                           /* 8-bit unsigned  */
typedef unsigned short int	WORD;                           /* 16-bit unsigned */
typedef unsigned long long	DWORD;                          /* 32-bit unsigned */

//--------------------------------------------------
//DECLARATIONS
//--------------------------------------------------
#define N_ON 1		// normal ON
#define N_OFF 0		// normal OFF
#define R_ON 0		// reverse ON
#define R_OFF 1		// reverse OFF

// EEPROM
#define EEPROM_SAVE_NUM		6
#define EEPROM_SAME_COUNT	4

// SW
#define SW_1		PORTCbits.RC1
#define SW_2		PORTCbits.RC2
#define SW_3		PORTBbits.RB5

// SLAVEAhX 0xB0 + (unit_no << 1)
#define I2C_SLAVE_ADD_UNIT1	0xB2	// unit1 slave address
#define I2C_SLAVE_ADD_UNIT2	0xB4	// unit2 slave address
#define I2C_SLAVE_ADD_UNIT3	0xB6	// unit3 slave address
#define I2C_SLAVE_ADD_UNIT4	0xB8	// unit4 slave address
// Data Address
#define I2C_NIXIE_NUMBER_TOP_ADR		0x00
#define I2C_NIXIE_CTRL1_TOP_ADR			0x04
#define I2C_NIXIE_CTRL2_TOP_ADR			0x08
#define I2C_NIXIE_BLINK_ON_TIME_L_ADR	0x0C
#define I2C_NIXIE_BLINK_ON_TIME_H_ADR	0x0D
#define I2C_NIXIE_BLINK_OFF_TIME_L_ADR	0x0E
#define I2C_NIXIE_BLINK_OFF_TIME_H_ADR	0x0F
// ctrl 1
#define NIXIE_CTRL_DOT_ALL		0x03	// NIXIEShbg
#define NIXIE_CTRL_DOT_R		0x01	// NIXIEEhbg
#define NIXIE_CTRL_DOT_L		0x02	// NIXIEhbg
#define NIXIE_CTRL_DOT_RB		0x04	// NIXIEEhbg_
#define NIXIE_CTRL_DOT_LB		0x08	// NIXIEhbg_
#define NIXIE_CTRL_BACK			0x10	// NIXIE\
#define NIXIE_CTRL_NUM_BLINK	0x20	// NIXIE_
#define NIXIE_CTRL_OFF			0x80	// NIXIE
// ctrl 2
#define NIXIE_CTRL_DATE_ALL		0x0F	// Srbg
#define NIXIE_CTRL_YEAR1000		0x01	// N\@̈
#define NIXIE_CTRL_YEAR100		0x02	// N\@S̈
#define NIXIE_CTRL_YEAR10		0x03	// N\@\̈
#define NIXIE_CTRL_YEAR1		0x04	// N\@̈
#define NIXIE_CTRL_MONTH10		0x05	// \@\̈
#define NIXIE_CTRL_MONTH1		0x06	// \@̈
#define NIXIE_CTRL_DAY10		0x07	// \@\̈
#define NIXIE_CTRL_DAY1			0x08	// \@̈
#define NIXIE_CTRL_HOUR10		0x09	// \@\̈
#define NIXIE_CTRL_HOUR1		0x0A	// \@̈
#define NIXIE_CTRL_MIN10		0x0B	// \@\̈
#define NIXIE_CTRL_MIN1			0x0C	// \@̈
#define NIXIE_CTRL_SEC10		0x0D	// b\@\̈
#define NIXIE_CTRL_SEC1			0x0E	// b\@̈
#define NIXIE_CTRL_TIME_BLINK_DOT	0x10	// Pb̓_Ńhbg
#define NIXIE_CTRL_TIME_BLINK_NUM	0x20	// Pb̓_Ő
#define NIXIE_RTC_BLINK_TIME	2500		// Pb̓_ŎON 2500 = 500ms / 0.2(timer)

//Nixie
#define NIXIE_TUBE_NUM			4	// NIXIE UNIT̃jLV[ǐ
#define NIXIE_UNIT_MAX_NUM		4	// NIXIE UNITőڑ



// NIXIEǃjbg@\
typedef struct
{
	BYTE	disp_num[NIXIE_TUBE_NUM];
	BYTE	disp_ctrl_1[NIXIE_TUBE_NUM];
	BYTE	disp_ctrl_2[NIXIE_TUBE_NUM];
} ST_NIXIE_DATA;
typedef union
{
	BYTE byte[NIXIE_TUBE_NUM*3];
	ST_NIXIE_DATA	nixie_data;
} UN_NIXIE_UNIT;

typedef union
{
	BYTE byte[NIXIE_TUBE_NUM*3*NIXIE_UNIT_MAX_NUM];
	UN_NIXIE_UNIT nixie_unit[NIXIE_UNIT_MAX_NUM];
} UN_NIXIE_UNITS;

//--------------------------------------------------
//Timer
//--------------------------------------------------
// 48MHz
/* Timer0 0.2ms */
/* 200us / ( 0.021us x 4 ) = 2,400  48MHz = 1/48us = 0.021us */
/* 2,400 / 1 = 2,400    vXP[=1 */
/* 0x10000 - 0x0960 = 0xF6A0    16bitJE^*/
#define WRITE_TIMER0_COUNT        0xF6A0        //Timer0̎

/* Timer1 1ms */
/* 1,000us / ( 0.021us x 4 ) = 12,000  48MHz = 1/48us = 0.021us */
/* 12,000 / 8 = 1,500    vXP[=8*/
/* 0x10000 - 0x5DC = 0xFA24    16bitJE^*/
#define WRITE_TIMER1_COUNT        0xFA24        //Timer1̎
/* Timer1 10ms */
/* 10,000us / ( 0.021us x 4 ) = 120,000  48MHz = 1/48us = 0.021us */
/* 120,000 / 8 = 15,000    vXP[=8*/
/* 0x10000 - 0x3A98 = 0xC568    16bitJE^*/
//#define WRITE_TIMER1_COUNT        0xC568        //Timer1̎
/* Timer1 20ms */
/* 20,000us / ( 0.021us x 4 ) = 240,000  48MHz = 1/48us = 0.021us */
/* 240,000 / 8 = 30,000    vXP[=8*/
/* 0x10000 - 0x7530 = 0x8AD0    16bitJE^*/
//#define WRITE_TIMER1_COUNT        0x8AD0        //Timer1̎
/* Timer1 100ms */
/* 100,000us / ( 0.021us x 4 ) = 1,200,000  48MHz = 1/48us = 0.021us */
/* 1,200,000 / 32 = 37,500    vXP[=32*/
/* 0x10000 - 0x927C = 0x6D84    16bitJE^*/
//#define WRITE_TIMER1_COUNT        0x6D84        //Timer1̎ 
/* Timer1 1000ms */
/* 1,000,000us / ( 0.021us x 4 ) = 12,000,000  48MHz = 1/48us = 0.021us */
/* 12,000,000 / 256 = 46,875    vXP[=256*/
/* 0x10000 - 0xB71B = 0x48E5    16bitJE^*/
//#define WRITE_TIMER1_COUNT        0x48E5        //Timer1̎ 


//--------------------------------------------------
//fBC֐
//--------------------------------------------------
// 48MHz = 1 0.083us
// 1ms = 12,000 = Delay1KTCYx(12);
// 10ms = 120,000 = Delay10KTCYx(12);
// 100ms = 1,200,000 = Delay10KTCYx(120)
#define DELAY_1ms() Delay1KTCYx(12)
#define DELAY_5ms() Delay1KTCYx(60)
#define DELAY_10ms() Delay10KTCYx(12)
#define DELAY_50ms() Delay10KTCYx(60)
#define DELAY_100ms() Delay10KTCYx(120)

//--------------------------------------------------
//ϐ
//--------------------------------------------------


// fobO
//extern unsigned char debug_array[16];

#endif //APP_H
